/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:WarArchiveMetadata.java 2372 2008-02-08 18:18:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import org.ow2.util.ee.deploy.api.deployable.WARDeployable;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;

/**
 * This class represents the annotation metadata of all classes of a War
 * file. From this class, we can get metadata of all classes.
 * @author Florent Benoit
 */
public class WarDeployableMetadata implements IWarDeployableMetadata {

    /**
     * Logger.
     */
    // private static Log logger = LogFactory.getLog(WarDeployableMetadata.class);

    /**
     * List of class annotations metadata.
     */
    private Map<String, IWarClassMetadata> warClassMetadataMap = null;

    /**
     * The war deployable.
     */
    private WARDeployable warDeployable;

    /**
     * Constructor.
     * @param warDeployable the war deployable
     */
    public WarDeployableMetadata(final WARDeployable warDeployable) {
        this.warDeployable = warDeployable;
        warClassMetadataMap = new HashMap<String, IWarClassMetadata>();
    }

    /**
     * Add annotation metadata for a given class.
     * @param warClassMetadata metadata of a class.
     */
    public void addWarClassMetadata(final IWarClassMetadata warClassMetadata) {
        String key = warClassMetadata.getJClass().getName();
        // already exists ?
        if (warClassMetadataMap.containsKey(key)) {
            throw new IllegalStateException("addWarClassMetadata : key already exists");
        }
        warClassMetadataMap.put(key, warClassMetadata);
    }


    /**
     * Get class annotation metadata.
     * @param className key of the map of annotations bean.
     * @return Bean annotation metadata of a given name.
     */
    public IWarClassMetadata getWarClassMetadata(final String className) {
        return warClassMetadataMap.get(className);
    }

    /**
     * Get collections of bean annotation metadata.
     * @return collections of bean annotation metadata.
     */
    public Collection<IWarClassMetadata> getWarClassMetadataCollection() {
        return warClassMetadataMap.values();
    }

    /**
     * @return the web archive
     */
    public WARDeployable getDeployable() {
        return warDeployable;
    }

}
