package org.ow2.util.ee.metadata.war.impl.configurator;

import org.ow2.util.ee.metadata.common.impl.configurator.CommonClassMetadataConfigurator;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarFieldMetadata;
import org.ow2.util.ee.metadata.war.api.IWarMethodMetadata;
import org.ow2.util.ee.metadata.war.impl.WarClassMetadata;
import org.ow2.util.ee.metadata.war.impl.WarDeployableMetadata;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.configurator.IMethodConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;


/**
 * WarClassMetadataConfigurator.
 * @author Gael Lalire
 */
public class WarClassMetadataConfigurator extends
        CommonClassMetadataConfigurator<IWarClassMetadata, IWarMethodMetadata, IWarFieldMetadata> {

    /**
     * WarClassMetadataConfigurator.
     * @param jClass signature
     * @param warArchiveMetadata parent
     */
    public WarClassMetadataConfigurator(final JClass jClass, final WarDeployableMetadata warArchiveMetadata) {
        super(new WarClassMetadata(jClass, warArchiveMetadata));
        registerAnnotationVisitor();
    }

    /**
     * @param jField signature
     * @return configurator
     */
    @Override
    protected IFieldConfigurator createFieldMetadataConfigurator(final JField jField) {
        return new WarFieldMetadataConfigurator(jField, getClassMetadata());
    }

    /**
     * @param jMethod signature
     * @return configurator
     */
    @Override
    protected IMethodConfigurator createMethodMetadataConfigurator(final JMethod jMethod) {
        return new WarMethodMetadataConfigurator(jMethod, getClassMetadata());
    }

    /**
     * add class to archive.
     */
    @Override
    public void configurationComplete() {
       IWarClassMetadata warClassMetadata = getClassMetadata();
       warClassMetadata.getWarDeployableMetadata().addWarClassMetadata(warClassMetadata);
    }

}
