/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WARDeploymentDescLoader.java 2999 2008-04-28 16:14:09Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl.xml.parsing;

import java.net.URL;

import org.ow2.util.ee.metadata.war.impl.xml.WAR;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.xml.DocumentParser;
import org.ow2.util.xml.DocumentParserException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * This class analyzes the WAR deployment descriptor and fill a struct with
 * getters.
 * @author Florent Benoit
 */
public class WARDeploymentDescLoader extends AbsWebLoader {

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(WARDeploymentDescLoader.class);


    /**
     * Constructor.
     * @param url the url that is pointing to the web xml file.
     */
    protected WARDeploymentDescLoader(final URL url) {
        super(url);
    }

    /**
     * Load the web.xml file.
     * @param url the URL of the XML file.
     * @throws ParsingException if parsing of XML file fails.
     * @return an application object.
     */
    public static WAR loadDeploymentDescriptor(final URL url) throws ParsingException {
        logger.debug("Analyzing url {0}", url);

        WARDeploymentDescLoader warDeploymentDescLoader = new WARDeploymentDescLoader(url);
        warDeploymentDescLoader.parse();
        return warDeploymentDescLoader.getWAR();
    }

    /**
     * Analyze the URL and build an EJB3 object which contains data of the XML.
     * @throws ParsingException if the analyze of the file fails.
     */
    public void parse() throws ParsingException {
        // Get document
        Document document = null;
        try {
            document = DocumentParser.getDocument(getURL(), false, new WAREntityResolver());
        } catch (DocumentParserException e) {
            throw new ParsingException("Cannot parse the url", e);
        }

        // Root element = <web-app>
        Element webAppRootElement = document.getDocumentElement();

        // Find and analyze the servlets
        analyzeServlets(webAppRootElement);

        // and listeners
        analyzeListeners(webAppRootElement);

        // and filters
        analyzeFilters(webAppRootElement);


    }

}
