/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WAREntityResolver.java 2950 2008-04-25 09:14:23Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl.xml.parsing;

import java.io.IOException;
import java.io.StringReader;

import org.ow2.util.xml.SchemaEntityResolver;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * Entity resolver allowing to find schema within the classloader.
 * @author Florent Benoit
 */
public class WAREntityResolver extends SchemaEntityResolver implements IEntityResolver {

    /**
     * All schemas used by WARs.
     */
    public static final String[] WAR_SCHEMAS = new String[] {PREFIX + JSP20_SCHEMA, PREFIX + JSP21_SCHEMA,
            PREFIX + WEBAPP24_SCHEMA, PREFIX + WEBAPP25_SCHEMA, PREFIX + CLIENT_SCHEMA, PREFIX + JAVAEE5_SCHEMA,
            PREFIX + J2EE14_SCHEMA, PREFIX + JAVAEE_WEBSERVICES_CLIENT_SCHEMA, PREFIX + J2EE_WEBSERVICES_CLIENT_SCHEMA,
            PREFIX + XML_SCHEMA};

    /**
     * Constructor. Finds the XSD with classloader.
     */
    public WAREntityResolver() {
        super(WAR_SCHEMAS);
    }

    /**
     * The Parser will call this method before opening any external entity
     * except the top-level document entity.
     * @param publicId The public identifier of the external entity being
     *        referenced, or null if none was supplied.
     * @param systemId The system identifier of the external entity being
     *        referenced.
     * @return An InputSource object describing the new input source, or null to
     *         request that the parser open a regular URI connection to the
     *         system identifier.
     * @throws SAXException Any SAX exception, possibly wrapping another
     *         exception.
     * @throws IOException A Java-specific IO exception, possibly the result of
     *         creating a new InputStream or Reader for the InputSource.
     */
    @Override
    public InputSource resolveEntity(final String publicId, final String systemId) throws IOException, SAXException {

        // Do not validate files
        return (new InputSource(new StringReader("")));
    }
}
